@@ -20,8 +20,8 @@ class PageTests(unittest.TestCase):
         pg = Page('Foo', fl, cfg)
         self.assertEqual(fl.page, pg)
         self.assertEqual(pg.url, '')
-        self.assertEqual(pg.abs_url, '/')
-        self.assertEqual(pg.canonical_url, 'https://example.com/')
+        self.assertEqual(pg.abs_url, None)
+        self.assertEqual(pg.canonical_url, None)
         self.assertEqual(pg.edit_url, None)
         self.assertEqual(pg.file, fl)
         self.assertEqual(pg.content, None)
@@ -44,8 +44,8 @@ class PageTests(unittest.TestCase):
         pg = Page('Foo', fl, cfg)
         pg.parent = 'foo'
         self.assertEqual(pg.url, 'sub1/')
-        self.assertEqual(pg.abs_url, '/sub1/')
-        self.assertEqual(pg.canonical_url, 'https://example.com/sub1/')
+        self.assertEqual(pg.abs_url, None)
+        self.assertEqual(pg.canonical_url, None)
         self.assertEqual(pg.edit_url, None)
         self.assertEqual(pg.file, fl)
         self.assertEqual(pg.content, None)
@@ -68,8 +68,8 @@ class PageTests(unittest.TestCase):
         pg = Page('Foo', fl, cfg)
         pg.parent = None  # non-homepage at nav root level; see #1919.
         self.assertEqual(pg.url, 'sub1/')
-        self.assertEqual(pg.abs_url, '/sub1/')
-        self.assertEqual(pg.canonical_url, 'https://example.com/sub1/')
+        self.assertEqual(pg.abs_url, None)
+        self.assertEqual(pg.canonical_url, None)
         self.assertEqual(pg.edit_url, None)
         self.assertEqual(pg.file, fl)
         self.assertEqual(pg.content, None)
@@ -92,8 +92,8 @@ class PageTests(unittest.TestCase):
         pg = Page('Foo', fl, cfg)
         pg.parent = None  # non-homepage at nav root level; see #1919.
         self.assertEqual(pg.url, 'sub1/index.html')
-        self.assertEqual(pg.abs_url, '/sub1/index.html')
-        self.assertEqual(pg.canonical_url, 'https://example.com/sub1/index.html')
+        self.assertEqual(pg.abs_url, None)
+        self.assertEqual(pg.canonical_url, None)
         self.assertEqual(pg.edit_url, None)
         self.assertEqual(pg.file, fl)
         self.assertEqual(pg.content, None)
@@ -116,8 +116,8 @@ class PageTests(unittest.TestCase):
         pg = Page('Foo', fl, cfg)
         pg.parent = 'foo'
         self.assertEqual(pg.url, 'sub1/non-index/')
-        self.assertEqual(pg.abs_url, '/sub1/non-index/')
-        self.assertEqual(pg.canonical_url, 'https://example.com/sub1/non-index/')
+        self.assertEqual(pg.abs_url, None)
+        self.assertEqual(pg.canonical_url, None)
         self.assertEqual(pg.edit_url, None)
         self.assertEqual(pg.file, fl)
         self.assertEqual(pg.content, None)
@@ -140,8 +140,8 @@ class PageTests(unittest.TestCase):
         pg = Page('Foo', fl, cfg)
         self.assertRegex(pg.update_date, r'\d{4}-\d{2}-\d{2}')
         self.assertEqual(pg.url, 'testing/')
-        self.assertEqual(pg.abs_url, '/testing/')
-        self.assertEqual(pg.canonical_url, 'https://example.com/testing/')
+        self.assertEqual(pg.abs_url, None)
+        self.assertEqual(pg.canonical_url, None)
         self.assertEqual(pg.edit_url, None)
         self.assertEqual(pg.file, fl)
         self.assertEqual(pg.content, None)
@@ -163,8 +163,8 @@ class PageTests(unittest.TestCase):
         fl = File('testing.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])
         pg = Page('Foo', fl, cfg)
         self.assertEqual(pg.url, 'testing.html')
-        self.assertEqual(pg.abs_url, '/testing.html')
-        self.assertEqual(pg.canonical_url, 'https://example.com/testing.html')
+        self.assertEqual(pg.abs_url, None)
+        self.assertEqual(pg.canonical_url, None)
         self.assertEqual(pg.edit_url, None)
         self.assertEqual(pg.file, fl)
         self.assertEqual(pg.content, None)
@@ -181,13 +181,13 @@ class PageTests(unittest.TestCase):
         self.assertEqual(pg.title, 'Foo')
         self.assertEqual(pg.toc, [])
 
-    def test_page_site_url_empty(self):
-        cfg = load_config(site_url='', use_directory_urls=False)
+    def test_page_canonical_url(self):
+        cfg = load_config(site_url='http://example.com')
         fl = File('testing.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])
         pg = Page('Foo', fl, cfg)
-        self.assertEqual(pg.url, 'testing.html')
-        self.assertEqual(pg.abs_url, None)
-        self.assertEqual(pg.canonical_url, None)
+        self.assertEqual(pg.url, 'testing/')
+        self.assertEqual(pg.abs_url, '/testing/')
+        self.assertEqual(pg.canonical_url, 'http://example.com/testing/')
         self.assertEqual(pg.edit_url, None)
         self.assertEqual(pg.file, fl)
         self.assertEqual(pg.content, None)
@@ -204,29 +204,6 @@ class PageTests(unittest.TestCase):
         self.assertEqual(pg.title, 'Foo')
         self.assertEqual(pg.toc, [])
 
-    def test_homepage_site_url_empty(self):
-        cfg = load_config(site_url='', use_directory_urls=False)
-        fl = File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])
-        pg = Page('Foo', fl, cfg)
-        self.assertEqual(pg.url, 'index.html')
-        self.assertEqual(pg.abs_url, None)
-        self.assertEqual(pg.canonical_url, None)
-        self.assertEqual(pg.edit_url, None)
-        self.assertEqual(pg.file, fl)
-        self.assertEqual(pg.content, None)
-        self.assertTrue(pg.is_homepage)
-        self.assertTrue(pg.is_index)
-        self.assertTrue(pg.is_page)
-        self.assertFalse(pg.is_section)
-        self.assertTrue(pg.is_top_level)
-        self.assertEqual(pg.markdown, None)
-        self.assertEqual(pg.meta, {})
-        self.assertEqual(pg.next_page, None)
-        self.assertEqual(pg.parent, None)
-        self.assertEqual(pg.previous_page, None)
-        self.assertEqual(pg.title, 'Foo')
-        self.assertEqual(pg.toc, [])
-
     def test_page_canonical_url_nested(self):
         cfg = load_config(site_url='http://example.com/foo/')
         fl = File('testing.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])
@@ -279,8 +256,8 @@ class PageTests(unittest.TestCase):
         pg = Page('Page Title', fl, cfg)
         pg.read_source(cfg)
         self.assertEqual(pg.url, 'testing/')
-        self.assertEqual(pg.abs_url, '/testing/')
-        self.assertEqual(pg.canonical_url, 'https://example.com/testing/')
+        self.assertEqual(pg.abs_url, None)
+        self.assertEqual(pg.canonical_url, None)
         self.assertEqual(pg.edit_url, None)
         self.assertEqual(pg.file, fl)
         self.assertEqual(pg.content, None)
@@ -303,8 +280,8 @@ class PageTests(unittest.TestCase):
         pg = Page(None, fl, cfg)
         pg.read_source(cfg)
         self.assertEqual(pg.url, 'testing/')
-        self.assertEqual(pg.abs_url, '/testing/')
-        self.assertEqual(pg.canonical_url, 'https://example.com/testing/')
+        self.assertEqual(pg.abs_url, None)
+        self.assertEqual(pg.canonical_url, None)
         self.assertEqual(pg.edit_url, None)
         self.assertEqual(pg.file, fl)
         self.assertEqual(pg.content, None)
@@ -327,8 +304,8 @@ class PageTests(unittest.TestCase):
         pg = Page(None, fl, cfg)
         pg.read_source(cfg)
         self.assertEqual(pg.url, 'metadata/')
-        self.assertEqual(pg.abs_url, '/metadata/')
-        self.assertEqual(pg.canonical_url, 'https://example.com/metadata/')
+        self.assertEqual(pg.abs_url, None)
+        self.assertEqual(pg.canonical_url, None)
         self.assertEqual(pg.edit_url, None)
         self.assertEqual(pg.file, fl)
         self.assertEqual(pg.content, None)
@@ -351,8 +328,8 @@ class PageTests(unittest.TestCase):
         pg = Page(None, fl, cfg)
         pg.read_source(cfg)
         self.assertEqual(pg.url, 'page-title/')
-        self.assertEqual(pg.abs_url, '/page-title/')
-        self.assertEqual(pg.canonical_url, 'https://example.com/page-title/')
+        self.assertEqual(pg.abs_url, None)
+        self.assertEqual(pg.canonical_url, None)
         self.assertEqual(pg.edit_url, None)
         self.assertEqual(pg.file, fl)
         self.assertEqual(pg.content, None)
@@ -375,8 +352,8 @@ class PageTests(unittest.TestCase):
         pg = Page(None, fl, cfg)
         pg.read_source(cfg)
         self.assertEqual(pg.url, 'pageTitle/')
-        self.assertEqual(pg.abs_url, '/pageTitle/')
-        self.assertEqual(pg.canonical_url, 'https://example.com/pageTitle/')
+        self.assertEqual(pg.abs_url, None)
+        self.assertEqual(pg.canonical_url, None)
         self.assertEqual(pg.edit_url, None)
         self.assertEqual(pg.file, fl)
         self.assertEqual(pg.content, None)
@@ -399,8 +376,8 @@ class PageTests(unittest.TestCase):
         pg = Page(None, fl, cfg)
         pg.read_source(cfg)
         self.assertEqual(pg.url, '')
-        self.assertEqual(pg.abs_url, '/')
-        self.assertEqual(pg.canonical_url, 'https://example.com/')
+        self.assertEqual(pg.abs_url, None)
+        self.assertEqual(pg.canonical_url, None)
         self.assertEqual(pg.edit_url, None)
         self.assertEqual(pg.file, fl)
         self.assertEqual(pg.content, None)
@@ -440,7 +417,7 @@ class PageTests(unittest.TestCase):
             cfg = load_config(docs_dir=docs_dir)
             fl = File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])
             pg = Page(None, fl, cfg)
-            # Create an UTF-8 Encoded file with BOM (as Micorsoft editors do). See #1186
+            # Create an UTF-8 Encoded file with BOM (as Microsoft editors do). See #1186
             with open(fl.abs_src_path, 'w', encoding='utf-8-sig') as f:
                 f.write(md_src)
             # Now read the file.
